@@ -64,11 +64,6 @@ class InitConnectionPool:
                         clazz = InitConnectionPool.getClass("lesscode.db.neo4j.neo4j_pool", fromlist="Neo4jPool")
                         # 执行用例
                         pool = await clazz(conn_info).create_pool()
-                    elif conn_info.dialect == "mysql_sqlalchemy":
-                        clazz = InitConnectionPool.getClass("lesscode.db.mysql_sqlalchemy.mysql_sqlalchemy_pool",
-                                                            fromlist="MysqlSqlAlchemyPool")
-                        # 执行用例
-                        pool = clazz(conn_info).sync_create_pool()
                     elif conn_info.dialect == "sqlalchemy":
                         clazz = InitConnectionPool.getClass("lesscode.db.sqlalchemy.sqlalchemy_pool",
                                                             fromlist="SqlAlchemyPool")
@@ -137,11 +132,6 @@ class InitConnectionPool:
                         clazz = InitConnectionPool.getClass("lesscode.db.neo4j.neo4j_pool", fromlist="Neo4jPool")
                         # 执行用例
                         pool = clazz(conn_info).sync_create_pool()
-                    elif conn_info.dialect == "mysql_sqlalchemy":
-                        clazz = InitConnectionPool.getClass("lesscode.db.mysql_sqlalchemy.mysql_sqlalchemy_pool",
-                                                            fromlist="MysqlSqlAlchemyPool")
-                        # 执行用例
-                        pool = clazz(conn_info).sync_create_pool()
                     elif conn_info.dialect == "sqlalchemy":
                         clazz = InitConnectionPool.getClass("lesscode.db.sqlalchemy.sqlalchemy_pool",
                                                             fromlist="SqlAlchemyPool")
