@@ -43,6 +43,7 @@ class BaseHandler(RequestHandler):
         # 如果想要使用自定义响应，设置self.original为True
         self.start_time = int(round(time.time() * 1000))
         self.end_time = int(round(time.time() * 1000))
+        self._request_id = f"self-{uuid.uuid1().hex}"
         self.original = False
         super().__init__(application, request, **kwargs)
         self.command_map = {}
@@ -121,7 +122,7 @@ class BaseHandler(RequestHandler):
         重写父类get请求处理方法，直接调用post方法统一处理
         :return:
         """
-        logging.info(f"Request-Id: {self.request.headers.get('Request-Id', '')}")
+        logging.info(f"Request-Id: {self.request.headers.get('Request-Id', self._request_id)}")
         self.process_request(self.request)
         await self.request_handler()
 
@@ -132,7 +133,7 @@ class BaseHandler(RequestHandler):
         通过不同的url指向不同处理方法
         :return:
         """
-        logging.info(f"Request-Id: {self.request.headers.get('Request-Id', '')}")
+        logging.info(f"Request-Id: {self.request.headers.get('Request-Id', self._request_id)}")
         self.process_request(self.request)
         await self.request_handler()
 
@@ -152,7 +153,7 @@ class BaseHandler(RequestHandler):
         通过不同的url指向不同处理方法
         :return:
         """
-        logging.info(f"Request-Id: {self.request.headers.get('Request-Id', '')}")
+        logging.info(f"Request-Id: {self.request.headers.get('Request-Id', self._request_id)}")
         self.process_request(self.request)
         await self.request_handler()
 
@@ -163,7 +164,7 @@ class BaseHandler(RequestHandler):
         通过不同的url指向不同处理方法
         :return:
         """
-        logging.info(f"Request-Id: {self.request.headers.get('Request-Id', '')}")
+        logging.info(f"Request-Id: {self.request.headers.get('Request-Id', self._request_id)}")
         self.process_request(self.request)
         await self.request_handler()
 
@@ -174,7 +175,7 @@ class BaseHandler(RequestHandler):
         通过不同的url指向不同处理方法
         :return:
         """
-        logging.info(f"Request-Id: {self.request.headers.get('Request-Id', '')}")
+        logging.info(f"Request-Id: {self.request.headers.get('Request-Id', self._request_id)}")
         self.process_request(self.request)
         await self.request_handler()
 
@@ -276,7 +277,7 @@ class BaseHandler(RequestHandler):
                 self.set_header("Access-Control-Allow-Origin", origin)
             else:
                 self.set_header("Access-Control-Allow-Origin", "*")
-            self.set_header("Request-Id", self.request.headers.get("Request-Id", ""))
+            self.set_header("Request-Id", self.request.headers.get("Request-Id", self._request_id))
             self.set_header("Plugin-Running-Time", self.request.headers.get("Plugin-Running-Time", ""))
             self.set_header("Access-Control-Allow-Headers",
                             "x-requested-with,Authorization,Can-read-cache,Content-Type,User")
