@@ -71,11 +71,98 @@ class StatusCode:
     NOT_ENTERPRISE_ACCOUNT = ("A0329", "当前帐号不是企业帐号")
     INVALID_ONLY_TOKEN = ("A0330", "单设备登录的token已失效")
     INVALID_REFRESH_TOKEN = ("A0331", "无效的REFRESH_TOKEN")
+    INSUFFICIENT_THIRD_PERMISSION = ("A0332", "三方权限不足")
+    INSUFFICIENT_OPERATION_PERMISSION = ("A0333", "操作权限不足")
+    INVALID_FILE_PARAMETERS = ("A0334", "无效的文件参数")
+    FILE_STORAGE_EXCEPTION = ("A0335", "文件存储异常")
+    DATABASE_CONNECT_EXCEPTION = ("A0336", "数据库连接异常")
+    UNABLE_OBTAIN_PHONE = ("A0340", "无法获取到手机号")
+
+    @staticmethod
+    def MONITOR_EXCEPTION(message):
+        """
+        监控异常
+        :param message: 替换的消息内容
+        :return:
+        """
+        return "A0390", "监控异常:{}".format(message)
+
+    @staticmethod
+    def SEVICE_EXCEPTION(message):
+        """
+        服务调用异常
+        :param message: 替换的消息内容
+        :return:
+        """
+        return "A0391", "服务调用异常:{}".format(message)
+
+    @staticmethod
+    def MESSAGE_QUEUE_EXCEPTION(message):
+        """
+        消息队列异常
+        :param message: 替换的消息内容
+        :return:
+        """
+        return "A0392", "消息队列异常:{}".format(message)
+
+    @staticmethod
+    def REQUEST_HEADER_EXCEPTION(message):
+        """
+        请求头异常
+        :param message: 替换的消息内容
+        :return:
+        """
+        return "A0393", "请求头异常:{}".format(message)
+
+    @staticmethod
+    def CHART_EXCEPTION(message):
+        """
+        图表异常
+        :param message: 替换的消息内容
+        :return:
+        """
+        return "A0394", "图表异常:{}".format(message)
+
+    @staticmethod
+    def ENCRYPTION_EXCEPTION(message):
+        """
+        加密异常
+        :param message: 替换的消息内容
+        :return:
+        """
+        return "A0395", "加密异常:{}".format(message)
+
+    @staticmethod
+    def TASK_EXCEPTION(message):
+        """
+        任务异常
+        :param message: 替换的消息内容
+        :return:
+        """
+        return "A0396", "任务异常:{}".format(message)
+
+    @staticmethod
+    def DATABASE_FIELD_EXCEPTION(message):
+        """
+        数据库字段异常
+        :param message: 替换的消息内容
+        :return:
+        """
+        return "A0397", "数据库字段异常:{}".format(message)
+
+    @staticmethod
+    def ThirdServiceError(message):
+        """
+        调用第三方接口失败
+        :param message: 替换的消息内容
+        :return:
+        """
+        return "A0398", "调用第三方接口失败:{}".format(message)
 
     @staticmethod
     def REQUIRED_PARAM_IS_EMPTY(message):
         """
-        用于自定义消息提示信息
+        请求参数异常
         :param message: 替换的消息内容
         :return:
         """
